@@ -5,7 +5,11 @@ class Error(Exception):
         self.meta = meta
 
     def __repr__(self):
-        return '<{} {}: {}>'.format(self.__class__.__name__, self.code, self.message)
+        return '<{} {}: {}>'.format(
+            self.__class__.__name__,
+            self.code,
+            self.message
+        )
 
     def has_code(self, code):
         return code in self.code
